@@ -5,7 +5,7 @@ from benedict.core import clone
 
 def filter(d, predicate):
     if not callable(predicate):
-        raise ValueError('predicate argument must be a callable.')
+        raise ValueError("predicate argument must be a callable.")
     new_dict = clone(d, empty=True)
     keys = list(d.keys())
     for key in keys:
